aboutsummaryrefslogtreecommitdiffstats
path: root/drv_generic_i2c.h
diff options
context:
space:
mode:
authorlfcorreia <lfcorreia@3ae390bd-cb1e-0410-b409-cd5a39f66f1f>2005-05-31 20:42:55 +0000
committerlfcorreia <lfcorreia@3ae390bd-cb1e-0410-b409-cd5a39f66f1f>2005-05-31 20:42:55 +0000
commit3a395fe2c2b26247213a0baf3766ac2817398d0c (patch)
treeebf9b589473f4adb3ca9eaeabf6cbc13dcec1229 /drv_generic_i2c.h
parent95a2d9bcb9481d4663b55fce529722a3b9fbdbed (diff)
downloadlcd4linux-3a395fe2c2b26247213a0baf3766ac2817398d0c.tar.gz
[lcd4linux @ 2005-05-31 20:42:54 by lfcorreia]
new file: lcd4linux_i2c.h avoid the problems detecting the proper I2C kernel include files rearrange all the other autoconf stuff to remove I2C detection new method by Paul Kamphuis to write to the I2C device git-svn-id: https://ssl.bulix.org/svn/lcd4linux/trunk@556 3ae390bd-cb1e-0410-b409-cd5a39f66f1f
Diffstat (limited to 'drv_generic_i2c.h')
-rw-r--r--drv_generic_i2c.h139
1 files changed, 76 insertions, 63 deletions
diff --git a/drv_generic_i2c.h b/drv_generic_i2c.h
index 64f4ed0..dd885be 100644
--- a/drv_generic_i2c.h
+++ b/drv_generic_i2c.h
@@ -1,64 +1,77 @@
-/* $Id: drv_generic_i2c.h,v 1.2 2005/05/08 04:32:44 reinelt Exp $
- *
- * generic driver helper for i2c displays
- *
- * Copyright (C) 2005 Luis F. Correia <luis.f.correia@seg-social.pt>
- * Copyright (C) 2005 The LCD4Linux Team <lcd4linux-devel@users.sourceforge.net>
- *
- * This file is part of LCD4Linux.
- *
- * LCD4Linux is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * LCD4Linux is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- *
+/* $Id: drv_generic_i2c.h,v 1.3 2005/05/31 20:42:55 lfcorreia Exp $
+ *
+ * generic driver helper for i2c displays
+ *
+ * Copyright (C) 2005 Luis F. Correia <luis.f.correia@seg-social.pt>
+ * Copyright (C) 2005 The LCD4Linux Team <lcd4linux-devel@users.sourceforge.net>
+ *
+ * This file is part of LCD4Linux.
+ *
+ * LCD4Linux is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ *
+ * LCD4Linux is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *
* $Log: drv_generic_i2c.h,v $
- * Revision 1.2 2005/05/08 04:32:44 reinelt
- * CodingStyle added and applied
- *
- * Revision 1.1 2005/03/28 19:39:23 reinelt
- * HD44780/I2C patch from Luis merged (still does not work for me)
- *
- *
- */
-
-/*
- *
- * exported fuctions:
- *
- * int drv_generic_i2c_open (void)
- * reads 'Port' entry from config and opens
- * the i2c port
- * returns 0 if ok, -1 on failure
- *
- * int drv_generic_i2c_close (void)
- * closes i2c port
- * returns 0 if ok, -1 on failure
- *
- * unsigned char drv_generic_i2c_wire (char *name, char *deflt)
- * reads wiring for one data signal from config
- * returns 1<<bitpos or 255 on error
- *
- * void drv_generic_i2c_data (unsigned char value)
- * put data bits on DB1..DB8
- */
-
-#ifndef _DRV_GENERIC_I2C_H_
-#define _DRV_GENERIC_I2C_H_
-
-int drv_generic_i2c_open(const char *section, const char *driver);
-int drv_generic_i2c_close(void);
-unsigned char drv_generic_i2c_wire(const char *name, const char *deflt);
-void drv_generic_i2c_data(const unsigned char data);
-
-#endif
+ * Revision 1.3 2005/05/31 20:42:55 lfcorreia
+ * new file: lcd4linux_i2c.h
+ * avoid the problems detecting the proper I2C kernel include files
+ *
+ * rearrange all the other autoconf stuff to remove I2C detection
+ *
+ * new method by Paul Kamphuis to write to the I2C device
+ *
+ * Revision 1.2 2005/05/08 04:32:44 reinelt
+ * CodingStyle added and applied
+ *
+ * Revision 1.1 2005/03/28 19:39:23 reinelt
+ * HD44780/I2C patch from Luis merged (still does not work for me)
+ *
+ *
+ */
+
+/*
+ *
+ * exported fuctions:
+ *
+ * int drv_generic_i2c_open (void)
+ * reads 'Port' entry from config and opens
+ * the i2c port
+ * returns 0 if ok, -1 on failure
+ *
+ * int drv_generic_i2c_close (void)
+ * closes i2c port
+ * returns 0 if ok, -1 on failure
+ *
+ * unsigned char drv_generic_i2c_wire (char *name, char *deflt)
+ * reads wiring for one data signal from config
+ * returns 1<<bitpos or 255 on error
+ *
+ * void drv_generic_i2c_data (unsigned char value)
+ * put data bits on DB1..DB8
+ *
+ * void drv_generic_i2c_command(unsigned char command, unsigned char *data,unsigned char length)
+ * send command and the data to the i2c device
+ *
+ */
+
+#ifndef _DRV_GENERIC_I2C_H_
+#define _DRV_GENERIC_I2C_H_
+
+int drv_generic_i2c_open(const char *section, const char *driver);
+int drv_generic_i2c_close(void);
+unsigned char drv_generic_i2c_wire(const char *name, const char *deflt);
+void drv_generic_i2c_data(const unsigned char data);
+void drv_generic_i2c_command(const unsigned char command, const unsigned char *data, const unsigned char length);
+
+#endif